with Spacecraft; use Spacecraft;

package Known_Satellites is

   Max_Satellites : constant := 10; -- arbitrary

   type Satellite_Reference is limited private;

   --  Insert the satellite Value into the repository of known satellites.
   --  The output Reference provides a reference to that satellite within the
   --  repository and can be used as such in other routines to retrieve and/or
   --  alter the corresponding satellite value.
   procedure Insert_Satellite
     (Value     : in     Satellite;
      Reference :    out Satellite_Reference);

   --  Update the satellite designated in the repository by Reference with the
   --  new Value.
   procedure Update_Satellite
     (Value     : in Satellite;
      Reference : in Satellite_Reference);

   --  Get a copy of the Value of the satellite designated by Reference. The
   --  repository is not changed.
   procedure Get_Satellite
     (Reference : in     Satellite_Reference;
      Value     :    out Satellite);

   --  A convenience routine that returns a copy of the satellite value
   --  designated by Reference. The repository is not changed.
   function Dereferenced (Reference : Satellite_Reference) return Satellite;

private

   type Satellite_Reference is range 0 .. Max_Satellites with
     Default_Value => 0;



end Known_Satellites;
