with Ada.Text_IO;  use Ada.Text_IO;
with Ada.Numerics; use Ada.Numerics;

procedure Display_Velocities is

   Feet_Per_Mile    : constant := 5_280.0;
   Miles_Per_KM     : constant := 0.62137;
   Minutes_Per_Hour : constant := 60.0;

   type Real is digits 13;

   type Countries is (USA, Russia);

   type Orbital_Data is array (Countries) of Real;

   Altitude     : Orbital_Data;
   Elapsed_Time : Orbital_Data;
   Revolutions  : Orbital_Data;

   Velocity : Real;
   Distance : Real;

begin
   Altitude := (USA    => 22_256_384.2 / Feet_Per_Mile,
                Russia => 12_147.7 * Miles_Per_KM);

   Elapsed_Time := (USA => 36_320.2 / Minutes_Per_Hour, Russia => 680.2);

   Revolutions := (USA => 10.0, Russia => 11.0);

   for Nation in Countries loop
      Distance := Revolutions (Nation) * 2.0 * Pi * Altitude (Nation);
      Velocity := Distance / Elapsed_Time (Nation);
      Put_Line ("Velocity for " & Countries'Image (Nation) &
                "'s satellite is " & Real'Image (Velocity) & " m.p.h.");
   end loop;
end Display_Velocities;
