with Ada.Text_IO;  use Ada.Text_IO;
with Ada.Numerics; use Ada.Numerics;

procedure Display_Velocities is

   Feet_Per_Mile    : constant := 5_280.0;
   Miles_Per_KM     : constant := 0.62137;
   Minutes_Per_Hour : constant := 60.0;

   type Real is digits 13;

   type Satellite is
      record
         Altitude     : Real;
         Elapsed_Time : Real;
         Revolutions  : Real;
      end record;

   type Countries is (USA, Russia);

   Satellites : array (Countries) of Satellite;
   Speed      : Real;

   function Velocity (This : Satellite) return Real is
      Distance : Real;
   begin
      Distance := This.Revolutions * 2.0 * Pi * This.Altitude;
      return Distance / This.Elapsed_Time;
   end Velocity;

begin
   Satellites (USA) :=
     (Altitude     => 22_256_384.2 / Feet_Per_Mile,
      Elapsed_Time => 36_320.2 / Minutes_Per_Hour,
      Revolutions  => 10.0);

   Satellites (Russia) :=
     (Altitude     => 12_147.7 * Miles_Per_KM,
      Elapsed_Time => 680.2,
      Revolutions  => 11.0);

   for Nation in Satellites'Range loop
      Speed := Velocity (Satellites (Nation));
      Put_Line ("Velocity for " & Countries'Image (Nation) &
                "'s satellite is " & Real'Image (Speed) & " m.p.h.");
   end loop;
end Display_Velocities;
