package Spacecraft with
   SPARK_Mode
is

   type Satellite is private;

   type Real is digits 13;

   --  Assume that the geostationary equatorial orbit (GEO) altitude (from the
   --  center of the Earth) is the largest.
   Max_Altitude : constant Real := 26_199.0;

   --  At low earth orbit, approx 250 miles, 1 orbit (revolution) takes
   --  approx 1.5 hours. That's 16 orbits per day, 5844 per year. Let's say a
   --  satellite has a lifetime of at most 10 years.
   Max_Revolutions : constant Real := 58_440.0;

   --  Therefore, the max distance ((2 * Pi * Max_Altitude) * Max_Revolutions)
   --  is 9_619_993_763.662 miles.

   --  For the elapsed time, we will be dividing by the time value so to avoid
   --  overflow we just need to ensure it is at least 1.0.

   subtype Valid_Altitude    is Real range 0.0 .. Max_Altitude;
   subtype Valid_Revolutions is Real range 0.0 .. Max_Revolutions;
   subtype Valid_Time        is Real range 1.0 .. Real'Last;

   function Velocity (This : Satellite) return Real with
     Global  => null,
     Depends => (Velocity'Result => This);

private

   type Satellite is record
      Altitude     : Valid_Altitude;
      Elapsed_Time : Valid_Time;
      Revolutions  : Valid_Revolutions;
   end record;

end Spacecraft;
